# coding: utf-8

"""
    Kimai 2 - API Docs

    JSON API for the Kimai 2 time-tracking software. Read more about its usage in the [API documentation](https://www.kimai.org/documentation/rest-api.html) and then download a [Swagger file](doc.json) for import e.g. in Postman. Be aware: it is not yet considered stable and BC breaks might happen.   # noqa: E501

    OpenAPI spec version: 0.5
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import kimai_python
from kimai_python.api.timesheet_api import TimesheetApi  # noqa: E501
from kimai_python.rest import ApiException


class TestTimesheetApi(unittest.TestCase):
    """TimesheetApi unit test stubs"""

    def setUp(self):
        self.api = kimai_python.api.timesheet_api.TimesheetApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_api_timesheets_active_get(self):
        """Test case for api_timesheets_active_get

        Returns the collection of active timesheet records  # noqa: E501
        """
        pass

    def test_api_timesheets_get(self):
        """Test case for api_timesheets_get

        Returns a collection of timesheet records  # noqa: E501
        """
        pass

    def test_api_timesheets_id_delete(self):
        """Test case for api_timesheets_id_delete

        Delete an existing timesheet record  # noqa: E501
        """
        pass

    def test_api_timesheets_id_duplicate_patch(self):
        """Test case for api_timesheets_id_duplicate_patch

        Duplicates an existing timesheet record  # noqa: E501
        """
        pass

    def test_api_timesheets_id_export_patch(self):
        """Test case for api_timesheets_id_export_patch

        Switch the export state of a timesheet record to (un-)lock it  # noqa: E501
        """
        pass

    def test_api_timesheets_id_get(self):
        """Test case for api_timesheets_id_get

        Returns one timesheet record  # noqa: E501
        """
        pass

    def test_api_timesheets_id_meta_patch(self):
        """Test case for api_timesheets_id_meta_patch

        Sets the value of a meta-field for an existing timesheet.  # noqa: E501
        """
        pass

    def test_api_timesheets_id_patch(self):
        """Test case for api_timesheets_id_patch

        Update an existing timesheet record  # noqa: E501
        """
        pass

    def test_api_timesheets_id_restart_patch(self):
        """Test case for api_timesheets_id_restart_patch

        Restarts a previously stopped timesheet record for the current user  # noqa: E501
        """
        pass

    def test_api_timesheets_id_stop_patch(self):
        """Test case for api_timesheets_id_stop_patch

        Stops an active timesheet record  # noqa: E501
        """
        pass

    def test_api_timesheets_post(self):
        """Test case for api_timesheets_post

        Creates a new timesheet record  # noqa: E501
        """
        pass

    def test_api_timesheets_recent_get(self):
        """Test case for api_timesheets_recent_get

        Returns the collection of recent user activities  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
