# coding: utf-8

# flake8: noqa

"""
    Kimai 2 - API Docs

    JSON API for the Kimai 2 time-tracking software. Read more about its usage in the [API documentation](https://www.kimai.org/documentation/rest-api.html) and then download a [Swagger file](doc.json) for import e.g. in Postman. Be aware: it is not yet considered stable and BC breaks might happen.   # noqa: E501

    OpenAPI spec version: 0.5
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

# import apis into sdk package
from kimai_python.api.activity_api import ActivityApi
from kimai_python.api.customer_api import CustomerApi
from kimai_python.api.default_api import DefaultApi
from kimai_python.api.project_api import ProjectApi
from kimai_python.api.tag_api import TagApi
from kimai_python.api.team_api import TeamApi
from kimai_python.api.timesheet_api import TimesheetApi
from kimai_python.api.user_api import UserApi

# import ApiClient
from kimai_python.api_client import ApiClient
from kimai_python.configuration import Configuration
# import models into sdk package
from kimai_python.models.activity import Activity
from kimai_python.models.activity_collection import ActivityCollection
from kimai_python.models.activity_edit_form import ActivityEditForm
from kimai_python.models.activity_entity import ActivityEntity
from kimai_python.models.activity_meta import ActivityMeta
from kimai_python.models.activity_meta_field import ActivityMetaField
from kimai_python.models.activity_rate import ActivityRate
from kimai_python.models.activity_rate_form import ActivityRateForm
from kimai_python.models.body import Body
from kimai_python.models.body1 import Body1
from kimai_python.models.body2 import Body2
from kimai_python.models.body3 import Body3
from kimai_python.models.body4 import Body4
from kimai_python.models.customer import Customer
from kimai_python.models.customer2 import Customer2
from kimai_python.models.customer_collection import CustomerCollection
from kimai_python.models.customer_edit_form import CustomerEditForm
from kimai_python.models.customer_entity import CustomerEntity
from kimai_python.models.customer_meta import CustomerMeta
from kimai_python.models.customer_meta_field import CustomerMetaField
from kimai_python.models.customer_rate import CustomerRate
from kimai_python.models.customer_rate_form import CustomerRateForm
from kimai_python.models.i18n_config import I18nConfig
from kimai_python.models.project import Project
from kimai_python.models.project2 import Project2
from kimai_python.models.project_collection import ProjectCollection
from kimai_python.models.project_edit_form import ProjectEditForm
from kimai_python.models.project_entity import ProjectEntity
from kimai_python.models.project_meta import ProjectMeta
from kimai_python.models.project_meta_field import ProjectMetaField
from kimai_python.models.project_rate import ProjectRate
from kimai_python.models.project_rate_form import ProjectRateForm
from kimai_python.models.tag_edit_form import TagEditForm
from kimai_python.models.tag_entity import TagEntity
from kimai_python.models.team import Team
from kimai_python.models.team2 import Team2
from kimai_python.models.team3 import Team3
from kimai_python.models.team4 import Team4
from kimai_python.models.team5 import Team5
from kimai_python.models.team_collection import TeamCollection
from kimai_python.models.team_edit_form import TeamEditForm
from kimai_python.models.team_entity import TeamEntity
from kimai_python.models.timesheet import Timesheet
from kimai_python.models.timesheet_collection import TimesheetCollection
from kimai_python.models.timesheet_config import TimesheetConfig
from kimai_python.models.timesheet_edit_form import TimesheetEditForm
from kimai_python.models.timesheet_entity import TimesheetEntity
from kimai_python.models.timesheet_meta import TimesheetMeta
from kimai_python.models.timesheet_meta2 import TimesheetMeta2
from kimai_python.models.timesheet_sub_collection import TimesheetSubCollection
from kimai_python.models.user import User
from kimai_python.models.user2 import User2
from kimai_python.models.user_collection import UserCollection
from kimai_python.models.user_create_form import UserCreateForm
from kimai_python.models.user_edit_form import UserEditForm
from kimai_python.models.user_entity import UserEntity
from kimai_python.models.version import Version
