# coding: utf-8

"""
    Kimai 2 - API Docs

    JSON API for the Kimai 2 time-tracking software. Read more about its usage in the [API documentation](https://www.kimai.org/documentation/rest-api.html) and then download a [Swagger file](doc.json) for import e.g. in Postman. Be aware: it is not yet considered stable and BC breaks might happen.   # noqa: E501

    OpenAPI spec version: 0.5
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import kimai_python
from kimai_python.api.customer_api import CustomerApi  # noqa: E501
from kimai_python.rest import ApiException


class TestCustomerApi(unittest.TestCase):
    """CustomerApi unit test stubs"""

    def setUp(self):
        self.api = kimai_python.api.customer_api.CustomerApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_api_customers_get(self):
        """Test case for api_customers_get

        Returns a collection of customers  # noqa: E501
        """
        pass

    def test_api_customers_id_get(self):
        """Test case for api_customers_id_get

        Returns one customer  # noqa: E501
        """
        pass

    def test_api_customers_id_meta_patch(self):
        """Test case for api_customers_id_meta_patch

        Sets the value of a meta-field for an existing customer  # noqa: E501
        """
        pass

    def test_api_customers_id_patch(self):
        """Test case for api_customers_id_patch

        Update an existing customer  # noqa: E501
        """
        pass

    def test_api_customers_id_rates_get(self):
        """Test case for api_customers_id_rates_get

        Returns a collection of all rates for one customer  # noqa: E501
        """
        pass

    def test_api_customers_id_rates_post(self):
        """Test case for api_customers_id_rates_post

        Adds a new rate to a customer  # noqa: E501
        """
        pass

    def test_api_customers_id_rates_rate_id_delete(self):
        """Test case for api_customers_id_rates_rate_id_delete

        Deletes one rate for an customer  # noqa: E501
        """
        pass

    def test_api_customers_post(self):
        """Test case for api_customers_post

        Creates a new customer  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
