# coding: utf-8

"""
    Kimai 2 - API Docs

    JSON API for the Kimai 2 time-tracking software. Read more about its usage in the [API documentation](https://www.kimai.org/documentation/rest-api.html) and then download a [Swagger file](doc.json) for import e.g. in Postman. Be aware: it is not yet considered stable and BC breaks might happen.   # noqa: E501

    OpenAPI spec version: 0.5
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import kimai_python
from kimai_python.api.team_api import TeamApi  # noqa: E501
from kimai_python.rest import ApiException


class TestTeamApi(unittest.TestCase):
    """TeamApi unit test stubs"""

    def setUp(self):
        self.api = kimai_python.api.team_api.TeamApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_api_teams_get(self):
        """Test case for api_teams_get

        Fetch all existing teams  # noqa: E501
        """
        pass

    def test_api_teams_id_customers_customer_id_delete(self):
        """Test case for api_teams_id_customers_customer_id_delete

        Revokes access for a customer from a team  # noqa: E501
        """
        pass

    def test_api_teams_id_customers_customer_id_post(self):
        """Test case for api_teams_id_customers_customer_id_post

        Grant the team access to a customer  # noqa: E501
        """
        pass

    def test_api_teams_id_delete(self):
        """Test case for api_teams_id_delete

        Delete a team  # noqa: E501
        """
        pass

    def test_api_teams_id_get(self):
        """Test case for api_teams_id_get

        Returns one team  # noqa: E501
        """
        pass

    def test_api_teams_id_members_user_id_delete(self):
        """Test case for api_teams_id_members_user_id_delete

        Removes a member from the team  # noqa: E501
        """
        pass

    def test_api_teams_id_members_user_id_post(self):
        """Test case for api_teams_id_members_user_id_post

        Add a new member to a team  # noqa: E501
        """
        pass

    def test_api_teams_id_patch(self):
        """Test case for api_teams_id_patch

        Update an existing team  # noqa: E501
        """
        pass

    def test_api_teams_id_projects_project_id_delete(self):
        """Test case for api_teams_id_projects_project_id_delete

        Revokes access for a project from a team  # noqa: E501
        """
        pass

    def test_api_teams_id_projects_project_id_post(self):
        """Test case for api_teams_id_projects_project_id_post

        Grant the team access to a project  # noqa: E501
        """
        pass

    def test_api_teams_post(self):
        """Test case for api_teams_post

        Creates a new team  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
